#
# spec file for package jira-cli
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           jira-cli
Version:        1.1.0
Release:        1.7
Summary:        CLI tool for Atlassian JIRA inspired by the Github CLI tool
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/ankitpokhrel/jira-cli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18

%define shortname jira

%description
JiraCLI is an interactive command line tool for Atlassian Jira that will help
you avoid Jira UI to some extent. This tool is not yet considered complete but
has all the essential features required to improve your workflow with Jira. The
tool started with the idea of making issue search and navigation as
straightforward as possible. The tool now includes all necessary features like
issue creation, cloning, linking, ticket transition, and much more. The TUI is
heavily inspired by the GitHub CLI.

%prep
%autosetup -a 1

%build
# Build the binary.
go build \
   -mod=vendor \
   -tags extended \
   -buildmode=pie \
   ./cmd/%{shortname}

%install
# Install the binary.
install -D -m 0755 %{shortname} "%{buildroot}/%{_bindir}/%{shortname}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{shortname}

%changelog
* Sun Aug 14 2022 chrisbcoutinho@gmail.com
- Update to version 1.1.0:
  * fix: Flickering issue (#436)
  * chore(doc): Add resources section
  * Add open collective
  * Add FUNDING.yml
  * dev: Upgrade jira to 8.22.1
  * chore(doc): Add missing articles (#423)
  * ehc: Increase max col width + some cleanup (#427)
  * fix(minor): Use pointer receiver to avoid heavy copying (#426)
  * chore: Remove deprecated ioutil usage (#422)
  * chore: s/\"%%s\"/%%q/g (#421)
  * feat: Make selection highlight customizable (#419)
  * fix: Issue with insecure TLS config (#413)
  * fix: Remove dead code in comment add (#411)
  * feat: Ability to add worklog (#410)
  * fix: Issue with default assignee and unassign from tui (#405)
  * doc: Add instructions for docker
* Wed Jul  6 2022 jkowalczyk@suse.com
- Initial package version 1.0.0:
  * fix: Use md ext to trigger syntax highlighting (#400)
  * dep: Upgrade cobra to 1.5 and viper to 1.12 (#399)
  * dep: Upgrade AlecAivazis/survey + sync editor ext (#398)
  * dep: Upgrade tview, tcell and testify (#397)
  * ci: Fix/refactor workflow (#396)
  * feat: Allow project filter in raw jql (#395)
  * fix: Editing issue with custom field in non interactive mode (#391)
  * ci: Upgrade golangci linter version (#394)
  * ci: Add workflow to publish docker image to ghcr (#392)
  * Add a Dockerfile (#387)
  * fix: Subtask clone (#383)
  * feat: Show subtasks in issue view (#382)
  * feat: Jira init non-interactive (#381)
  * fix: Issue with query param in user assignment (#380)
  * doc: Change some wordings
  * doc: Update contribution notice
  * feat: Support custom fields on issue edit (#377)
  * chore: Bump copyright year
  * doc: Minor updates
  * feat: Allow removing fixVersions on edit (#376)
  * feat: Allow removing component on edit (#374)
  * dep: Upgrade cobra to 1.4.0 (#373)
  * fix: Support creating issues with custom subtask type (#372)
  * feat: Allow removing labels on edit (#371)
  * fix!: Append components on edit instead of overriding (#368)
  * feat: Allow to edit release-info/fixVersions (#365)
  * feat: Allow to set custom fields on epic create (#364)
  * chore: Minor refactoring and doc update
  * fix: Add additional check for total boards returned (#360)
  * feat: Add issues unlink command (#347)
  * fix!: Replace limit flag with paginate (#359)
  * doc: Update some details related to API tokens
  * feat: Add support for OS keyrings/-chains (#348)
  * fix: Assign parent key as is on edit (#351)
  * fix: OOM bug on issue view (#350)
  * fix: Issue with assigning user (#321)
  * doc: Add details for custom flag
  * feat: Support custom fields on issue create (#319)
  * ci: Upgrade linter
  * feat: Ability to delete issue (#336)
  * chore: Improve docs
  * chore: Minor refactoring and fixes (#335)
  * feat: Initial support for netrc (#329)
  * feat: Support refresh for issues list (#325)
  * fix: Panic on empty sub-list (#330)
  * chore: Minor refactoring and fixes (#328)
  * feat: Support auth with personal access tokens (#327)
  * doc: Clarify help for sprint issues column flag (#320)
  * fix: Jira wiki parser (#326)
  * feat: Add search option for boards on jira init (#322)
  * feat: Use md ext for tmp file to trigger syntax highlighting (#318)
  * feat!: Append labels instead of overwritting on edit (#300)
  * fix: Get subtask handle from config (#296)
  * fix: Respect GLAMOUR_STYLE env on issue view (#317)
  * refactor!: Move boards and project list to subcommand (#314)
  * dep: Upgrade outdated packages (#311)
  * dep: Upgrade rivo/tview to latest (#310)
  * dep: Upgrade charmbracelet/glamour to 0.5.0 (#309)
  * feat: Add --no-browser option to open cmd (#308)
  * feat: Allow insecure TLS (#305)
  * fix: Jira client should respect timeout opt (#304)
  * chore: Change the logo color to be white for consitency (#299)
  * doc: Add backers badge
  * dev: Upgrade jira
  * fix(cfg): Strip trailing slash on server name (#295)
  * feat: Allow to set fixVersions on issue creation (#276)
  * fix: Config generation issue (#275)
  * doc: Add the FreeBSD and NetBSD badge. (#270)
  * dev: Fix Makefile compatiblity with Make 3.81 (#252)
